MigrationConfig

Struct MigrationConfig 

pub struct MigrationConfig {
    pub path: PathBuf,
    pub prefix_style: MigrationPrefixStyle,
    pub checksums: bool,
    pub statement_breakpoints: bool,
}
Configuration for migration operations

Fields

path: PathBuf

Path to the migrations folder

prefix_style: MigrationPrefixStyle

Style of migration file prefixes

checksums: bool

Whether the history file should store and verify checksums of the migration files so that they may not be changed.

statement_breakpoints: bool

Whether to add statement breakpoint comments to generated SQL migration files. These comments mark boundaries where SQL statements should be split for execution. This is needed because different databases have different batching capabilities: some (like PostgreSQL) can execute multiple statements in one batch, while others require each statement to be executed separately.

Implementations

Source

impl MigrationConfig

pub fn new() -> Self

Create a new MigrationConfig with default values

pub fn path(self, path: impl Into<PathBuf>) -> Self

Set the migrations path

pub fn prefix_style(self, style: MigrationPrefixStyle) -> Self

Set the migration prefix style

pub fn get_migrations_dir(&self) -> PathBuf

Returns the directory of the migration files derived from path.

pub fn get_snapshots_dir(&self) -> PathBuf

Returns the directory of the snapshot files derived from path.

pub fn get_history_file_path(&self) -> PathBuf

Get the path to the history file