pub struct HistoryFile { /* private fields */ }Expand description
History file containing the record of all applied migrations
Implementations
Sourceimpl HistoryFile
impl HistoryFile
Sourcepub fn load_or_default(path: impl AsRef<Path>) -> Result<Self>
pub fn load_or_default(path: impl AsRef<Path>) -> Result<Self>
Loads the history file, or returns an empty one if it does not exist
pub fn migrations(&self) -> &[HistoryFileMigration]
Sourcepub fn next_migration_number(&self) -> u32
pub fn next_migration_number(&self) -> u32
Get the next migration number by parsing the last migration’s name
Sourcepub fn add_migration(&mut self, migration: HistoryFileMigration)
pub fn add_migration(&mut self, migration: HistoryFileMigration)
Add a migration to the history
Sourcepub fn remove_migration(&mut self, index: usize)
pub fn remove_migration(&mut self, index: usize)
Remove a migration from the history by index